-- Project: Bricolage
-- VERSION: $Revision: 1.5.2.1 $
--
-- $Date: 2002/02/27 00:57:22 $
-- Target DBMS: PostgreSQL 7.1.2
-- Author: Michael Soderstrom <miraso@pacbell.net>
--
-- The sql representation of Media Assets.

-- -----------------------------------------------------------------------------
-- Sequences

-- Unique IDs for the media table
CREATE SEQUENCE seq_media START 1024;

CREATE SEQUENCE seq_media_instance START 1024;

-- Unique ids for the story_contributor table
CREATE SEQUENCE seq_media__contributor START 1024;

-- Unique IDs for the media_member table
CREATE SEQUENCE seq_media_member START 1024;

CREATE SEQUENCE seq_image_member START  1024;
CREATE SEQUENCE seq_audio_member START  1024;
CREATE SEQUENCE seq_video_member START  1024;

CREATE SEQUENCE seq_media_fields START 1024;

-- Unique IDs for the attr_media table
CREATE SEQUENCE seq_attr_media START  1024;

-- Unique IDs for each attr_media_*_val table
CREATE SEQUENCE seq_attr_media_val START 1024;

-- Unique IDs for the media_meta table
CREATE SEQUENCE seq_attr_media_meta START 1024;


-- -----------------------------------------------------------------------------
-- Table media
-- 
-- Description: The Media table this houses the data for a given media asset
-- 				and its related asset_version_data
--

CREATE TABLE media (
    id               NUMERIC(10,0)   NOT NULL
                                     DEFAULT NEXTVAL('seq_media'),
    element__id   NUMERIC(10,0)   NOT NULL,
    priority          NUMERIC(1,0)   NOT NULL
                                     DEFAULT 3
                                     CONSTRAINT ck_media__priority
                                       CHECK (priority BETWEEN 1 AND 5),
    source__id       NUMERIC(10,0)   NOT NULL,
    current_version  NUMERIC(10,0),
    usr__id          NUMERIC(10,0),
    keyword_grp__id  NUMERIC(10,0),
    publish_date     TIMESTAMP,
    expire_date      TIMESTAMP,
    cover_date       TIMESTAMP,
	workflow__id	 NUMERIC(10,0),
    publish_status   NUMERIC(1,0)    NOT NULL
                                     DEFAULT 0
                                     CONSTRAINT ck_media__publish_status 
                                       CHECK (publish_status IN (0,1)),
    active           NUMERIC(1,0)    NOT NULL
                                     DEFAULT 1
                                     CONSTRAINT ck_media__active
                                       CHECK (active IN (0,1)),
    CONSTRAINT pk_media__id PRIMARY KEY (id)
);

-- -----------------------------------------------------------------------------
-- Table: media_instance
--
-- Description: An instance of a media object
--
--

CREATE TABLE media_instance (
    id           	NUMERIC(10,0)   NOT NULL
                                 	DEFAULT NEXTVAL('seq_media_instance'),
    name                VARCHAR(256),
    description         VARCHAR(1024),
    media__id    	NUMERIC(10,0)   NOT NULL,
    usr__id      	NUMERIC(10,0)   NOT NULL,
    version      	NUMERIC(10,0),
    category__id        NUMERIC(10,0)   NOT NULL,
    media_type__id	NUMERIC(10,0),
    file_size    	NUMERIC(10,0),
    file_name    	VARCHAR(256),
    location     	VARCHAR(256),
    uri          	VARCHAR(256),
    checked_out  	NUMERIC(1,0)    NOT NULL
                                 	DEFAULT 0
                                 	CONSTRAINT ck_media_instance__checked_out 
                                   	CHECK (checked_out IN(0,1)),
    CONSTRAINT pk_media_instance__id PRIMARY KEY (id)
);

-- -----------------------------------------------------------------------------
-- Table: media_fields
-- 
-- Description: A mapping table between Media classes and functions that
--				Will be run against uploaded files
-- 
CREATE TABLE media_fields (
    id              NUMERIC(10,0)  NOT NULL 	
                                   DEFAULT NEXTVAL('seq_media_fields'),
    biz_pkg         NUMERIC(10,0)  NOT NULL,
    name            VARCHAR(32)    NOT NULL,
    function_name   VARCHAR(256)   NOT NULL,
    active          NUMERIC(1,0)   NOT NULL
                                   DEFAULT 1
                                   CONSTRAINT ck_media_fields__active
                                     CHECK (active IN(0,1)) ,
    CONSTRAINT pk_media_fields__id PRIMARY KEY (id)
);

-- -----------------------------------------------------------------------------
-- Table media__contributor
-- 
-- Description: mapping tables between story instances and contributors
--
--

CREATE TABLE media__contributor (
    id                  NUMERIC(10,0)   NOT NULL
                                        DEFAULT NEXTVAL('seq_media__contributor'),
    media_instance__id  NUMERIC(10,0)   NOT NULL,
    member__id          NUMERIC(10,0)   NOT NULL,
    place               NUMERIC(3,0)    NOT NULL,
    role                VARCHAR(256),
    CONSTRAINT pk_media_category_id PRIMARY KEY (id)
);


-- -----------------------------------------------------------------------------
-- Table: media_member
-- 
-- Description: The link between media objects and member objects
--

CREATE TABLE media_member (
    id          NUMERIC(10,0)  NOT NULL
                               DEFAULT NEXTVAL('seq_media_member'),
    object_id   NUMERIC(10,0)  NOT NULL,
    member__id  NUMERIC(10,0)  NOT NULL,
    CONSTRAINT pk_media_member__id PRIMARY KEY (id)
);


-- -----------------------------------------------------------------------------
-- Table: image_member
--
-- Description: The link between image objects and member objects
--

CREATE TABLE image_member (
    id          NUMERIC(10,0)  NOT NULL
                               DEFAULT NEXTVAL('seq_image_member'),
    object_id   NUMERIC(10,0)  NOT NULL,
    member__id  NUMERIC(10,0)  NOT NULL,
    CONSTRAINT pk_image_member__id PRIMARY KEY (id)
);


-- -----------------------------------------------------------------------------
-- Table: audio_member
--
-- Description: The link between audio objects and member objects
--

CREATE TABLE audio_member (
    id          NUMERIC(10,0)  NOT NULL
                               DEFAULT NEXTVAL('seq_audio_member'),
    object_id   NUMERIC(10,0)  NOT NULL,
    member__id  NUMERIC(10,0)  NOT NULL,
    CONSTRAINT pk_audio_member__id PRIMARY KEY (id)
);

-- -----------------------------------------------------------------------------
-- Table: video_member
--
-- Description: The link between video objects and member objects
--

CREATE TABLE video_member (
    id          NUMERIC(10,0)  NOT NULL
                               DEFAULT NEXTVAL('seq_video_member'),
    object_id   NUMERIC(10,0)  NOT NULL,
    member__id  NUMERIC(10,0)  NOT NULL,
    CONSTRAINT pk_video_member__id PRIMARY KEY (id)
);


-- Table: attr_media
--
-- Description: A table to represent types of attributes.  A type is defined by
--              its subsystem, its media ID and an attribute name.

CREATE TABLE attr_media (
    id         NUMERIC(10)   NOT NULL
                             DEFAULT NEXTVAL('seq_attr_media'),
    subsys     VARCHAR(256)  NOT NULL,
    name       VARCHAR(256)  NOT NULL,
    sql_type   VARCHAR(30)   NOT NULL,
    active     NUMERIC(1)    DEFAULT 1
                             NOT NULL
                             CONSTRAINT ck_attr_media__active CHECK (active IN (0,1)),
   CONSTRAINT pk_attr_media__id PRIMARY KEY (id)
);


-- ------------------------------------------------------------------------------- Table: attr_media_val
--
-- Description: A table to hold attribute values.

CREATE TABLE attr_media_val (
    id           NUMERIC(10)     NOT NULL
                                 DEFAULT NEXTVAL('seq_attr_media_val'),
    object__id   NUMERIC(10)     NOT NULL,
    attr__id     NUMERIC(10)     NOT NULL,
    date_val     TIMESTAMP,
    short_val    VARCHAR(1024),
    blob_val     TEXT,
    serial       NUMERIC(1)      DEFAULT 0,
    active       NUMERIC(1)      DEFAULT 1
                                 NOT NULL
                                 CONSTRAINT ck_attr_media_val__active CHECK (active IN (0,1)),
    CONSTRAINT pk_attr_media_val__id PRIMARY KEY (id)
);


-- ------------------------------------------------------------------------------- Table: attr_media_meta
--
-- Description: A table to represent metadata on types of attributes.

CREATE TABLE attr_media_meta (
    id        NUMERIC(10)     NOT NULL
                              DEFAULT NEXTVAL('seq_attr_media_meta'),
    attr__id  NUMERIC(10)     NOT NULL,
    name      VARCHAR(256)    NOT NULL,
    value     VARCHAR(2048),
    active    NUMERIC(1)      DEFAULT 1
                              NOT NULL
                              CONSTRAINT ck_attr_media_meta__active CHECK (active IN (0,1)),
   CONSTRAINT pk_attr_media_meta__id PRIMARY KEY (id)
);



--
-- INDEXES.
--

-- media
CREATE INDEX idx_media__publish_date ON media(publish_date);
CREATE INDEX idx_media__cover_date ON media(cover_date);
CREATE INDEX fkx_source__media ON media(source__id);
CREATE INDEX fkx_usr__media ON media(usr__id);
CREATE INDEX fkx_kw__media ON media(keyword_grp__id);
CREATE INDEX fkx_element__media ON media(element__id);

-- media_instance
CREATE INDEX idx_media_instance__name ON media_instance(LOWER(name));
CREATE INDEX idx_media_instance__file_name ON media_instance(LOWER(file_name));
CREATE INDEX idx_media_instance__uri ON media_instance(LOWER(uri));
CREATE INDEX fkx_media__media_instance ON media_instance(media__id);
CREATE INDEX fkx_usr__media_instance ON media_instance(usr__id);
CREATE INDEX fkx_media_type__media_instance ON media_instance(media_type__id);
CREATE INDEX fkx_category__media_instance ON media_instance(category__id);

-- media_member.
CREATE INDEX fkx_media__media_member ON media_member(object_id);
CREATE INDEX fkx_member__media_member ON media_member(member__id);

-- image_member.
CREATE INDEX fkx_image__image_member ON image_member(object_id);
CREATE INDEX fkx_member__image_member ON image_member(member__id);

-- audio_member.
CREATE INDEX fkx_audio__audio_member ON audio_member(object_id);
CREATE INDEX fkx_member__audio_member ON audio_member(member__id);

-- video_member.
CREATE INDEX fkx_video__video_member ON video_member(object_id);
CREATE INDEX fkx_member__video_member ON video_member(member__id);

-- Unique index on subsystem/name pair
CREATE UNIQUE INDEX udx_attr_media__subsys__name ON attr_media(subsys, name);

-- Indexes on name and subsys.
CREATE INDEX idx_attr_media__name ON attr_media(LOWER(name));
CREATE INDEX idx_attr_media__subsys ON attr_media(LOWER(subsys));

-- Unique index on object__id/attr__id pair
CREATE UNIQUE INDEX udx_attr_media_val__obj_attr ON attr_media_val (object__id,attr__id);

-- FK indexes on object__id and attr__id.
CREATE INDEX fkx_media__attr_media_val ON attr_media_val(object__id);
CREATE INDEX fkx_attr_media__attr_media_val ON attr_media_val(attr__id);

-- Unique index on attr__id/name pair
CREATE UNIQUE INDEX udx_attr_media_meta__attr_name ON attr_media_meta (attr__id, name);

-- Index on meta name.
CREATE INDEX idx_attr_media_meta__name ON attr_media_meta(LOWER(name));

-- FK index on attr__id.
CREATE INDEX fkx_attr_media__attr_media_meta ON attr_media_meta(attr__id);



